@@ -38,6 +38,9 @@ class Discrete:
         if not hasattr(self, 'export_flags_tex'):
             self.export_flags_tex = []
 
+        self.input_list = []   # references to input variables
+        self.param_list = []  # references to parameters
+
         self.x_set = list()
         self.y_set = list()   # NOT being used
 
@@ -265,6 +268,9 @@ class LessThan(Discrete):
         self.export_flags = ['z0', 'z1']
         self.export_flags_tex = ['z_0', 'z_1']
 
+        self.input_list.extend([self.u])
+        self.param_list.extend([self.bound])
+
         self.has_check_var = True
 
     def check_var(self, *args, **kwargs):
@@ -376,6 +382,9 @@ class Limiter(Discrete):
         self.export_flags.append('zi')
         self.export_flags_tex.append('z_i')
 
+        self.input_list.extend([self.u])
+        self.param_list.extend([self.lower, self.upper])
+
         if not self.no_lower:
             self.export_flags.append('zl')
             self.export_flags_tex.append('z_l')
@@ -737,9 +746,9 @@ class AntiWindup(Limiter):
             # logger.debug(f'AntiWindup for states {self.state.a[idx]}')
 
         # Very important note:
-        # `System.fg_to_dae` is called after `System.l_update_eq`, which calls this function.
-        # Equation values set in `self.state.e` is collected by `System._e_to_dae`, while
-        # variable values are collected by the separate loop in `System.fg_to_dae`.
+        # The set equation values and variable values are collected by `System.fg_to_dae`:
+        # - Equation values is collected by `System._e_to_dae`,
+        # - Variable values are collected at the end of `System.fg_to_dae`.
         # Also, equation values are processed in `TDS` for resetting the `q`.
 
 
@@ -760,7 +769,7 @@ class RateLimiter(Discrete):
     """
 
     def __init__(self, u, lower, upper, enable=True,
-                 no_lower=False, no_upper=False, lower_cond=None, upper_cond=None,
+                 no_lower=False, no_upper=False, lower_cond=1, upper_cond=1,
                  name=None, tex_name=None, info=None):
         Discrete.__init__(self, name=name, tex_name=tex_name, info=info)
         self.u = u
@@ -801,6 +810,9 @@ class RateLimiter(Discrete):
             self.export_flags_tex.append('z_{ur}')
             self.warn_flags.append(('zur', 'upper'))
 
+        self.param_list.extend([self.rate_lower, self.rate_upper,
+                                self.rate_lower_cond, self.rate_upper_cond])
+
     def check_eq(self, **kwargs):
         if not self.enable:
             return
@@ -864,6 +876,13 @@ class Selector(Discrete):
     A potential bug when more than two inputs are provided, and values in different inputs are equal.
     Only two inputs are allowed.
 
+    .. deprecated:: 1.5.9
+
+        Use of this class for comparison-based output is discouraged.
+        Instead, use `LessThan` and `Limiter` to construct piesewise equations.
+
+        See the new implementation of ``HVGate`` and ``LVGate``.
+
     Examples
     --------
     Example 1: select the largest value between `v0` and `v1` and put it into vmax.
@@ -890,9 +909,6 @@ class Selector(Discrete):
     --------
     numpy.ufunc.reduce : NumPy reduce function
 
-    andes.core.block.HVGate
-
-    andes.core.block.LVGate
     """
 
     def __init__(self, *args, fun, tex_name=None, info=None):
@@ -911,6 +927,8 @@ class Selector(Discrete):
         self.export_flags = [f's{i}' for i in range(len(self.input_vars))]
         self.export_flags_tex = [f's_{i}' for i in range(len(self.input_vars))]
 
+        self.input_list = args
+
         self.has_check_var = True
 
     def check_var(self, *args, **kwargs):
@@ -986,6 +1004,7 @@ class Switcher(Discrete):
 
         self.export_flags = [f's{i}' for i in range(len(options))]
         self.export_flags_tex = [f's_{i}' for i in range(len(options))]
+        self.input_list.extend([self.u])
 
         self.has_check_var = True
 
@@ -1076,6 +1095,8 @@ class DeadBand(Limiter):
 
         self.center = dummify(center)  # CURRENTLY NOT IN USE
 
+        self.param_list.extend([self.center])
+
     def check_var(self, *args, **kwargs):
         """
         Notes
@@ -1211,6 +1232,8 @@ class Delay(Discrete):
         self.delay = delay
         self.export_flags = ['v']
         self.export_flags_tex = ['v']
+        self.input_list.extend([u])
+
         self.has_check_var = True
 
         self.t = np.array([0])
@@ -1335,6 +1358,8 @@ class Sampling(Discrete):
 
         self.export_flags = ['v']
         self.export_flags_tex = ['v']
+        self.input_list.extend([self.u])
+
         self.has_check_var = True
 
         self.v = np.array([0])
@@ -1439,6 +1464,8 @@ class ShuntAdjust(Discrete):
         self.err_tol = err_tol
 
         self.has_check_var = True
+        self.input_list.extend([self.v])
+        self.param_list.extend([self.lower, self.upper, self.u])
 
         self.t_last = None
         self.t_enable = None
