@@ -586,7 +586,7 @@ class TDSData:
             ax.autoscale(axis='y')
 
         if grid:
-            ax.grid(b=True, linestyle='--')
+            ax.grid(True, linestyle='--')
 
         if yheader is None:
             legend = False
@@ -639,7 +639,7 @@ class TDSData:
 
         plt.draw()
 
-        if savefig is not None:
+        if savefig:
             if save_format is None:
                 save_format = 'png'
 
