@@ -29,7 +29,7 @@ from andes.io.streaming import Streaming
 from andes.models import file_classes
 from andes.models.group import GroupBase
 from andes.routines import all_routines
-from andes.shared import (Pool, Process, dilled_vars, jac_names, matrix, np,
+from andes.shared import (NCPUS_PHYSICAL, Pool, Process, dilled_vars, jac_names, matrix, np,
                           sparse, spmatrix,)
 from andes.utils.misc import elapsed
 from andes.utils.paths import (andes_root, confirm_overwrite, get_config_path,
@@ -106,15 +106,16 @@ class System:
             self.options.update(options)
         if kwargs:
             self.options.update(kwargs)
-        self.calls = OrderedDict()         # a dictionary with model names (keys) and their ``calls`` instance
-        self.models = OrderedDict()        # model names and instances
-        self.groups = OrderedDict()        # group names and instances
-        self.routines = OrderedDict()      # routine names and instances
-        self.switch_times = np.array([])   # an array of ordered event switching times
-        self.switch_dict = OrderedDict()   # time: OrderedDict of associated models
-        self.with_calls = False            # if generated function calls have been loaded
-        self.n_switches = 0                # number of elements in `self.switch_times`
-        self.exit_code = 0                 # command-line exit code, 0 - normal, others - error.
+        self.calls = OrderedDict()           # a dictionary with model names (keys) and their ``calls`` instance
+        self.models = OrderedDict()          # model names and instances
+        self.model_aliases = OrderedDict()   # alias: model instance
+        self.groups = OrderedDict()          # group names and instances
+        self.routines = OrderedDict()        # routine names and instances
+        self.switch_times = np.array([])     # an array of ordered event switching times
+        self.switch_dict = OrderedDict()     # time: OrderedDict of associated models
+        self.with_calls = False              # if generated function calls have been loaded
+        self.n_switches = 0                  # number of elements in `self.switch_times`
+        self.exit_code = 0                   # command-line exit code, 0 - normal, others - error.
 
         # get and load default config file
         self._config_path = get_config_path()
@@ -269,7 +270,7 @@ class System:
         self._adders = dict(f=list(), g=list(), x=list(), y=list())
         self._setters = dict(f=list(), g=list(), x=list(), y=list())
 
-    def prepare(self, quick=False, incremental=False, models=None, nomp=False, ncpu=os.cpu_count()):
+    def prepare(self, quick=False, incremental=False, models=None, nomp=False, ncpu=NCPUS_PHYSICAL):
         """
         Generate numerical functions from symbolically defined models.
 
@@ -517,7 +518,7 @@ class System:
 
         This methods calls the ``add`` method of `model` and registers the device `idx` to group.
         """
-        if model not in self.models:
+        if model not in self.models and (model not in self.model_aliases):
             logger.warning("<%s> is not an existing model.", model)
             return
 
@@ -533,7 +534,7 @@ class System:
             param_dict.update(kwargs)
 
         idx = param_dict.pop('idx', None)
-        if idx is np.nan:
+        if idx is not None and (not isinstance(idx, str) and np.isnan(idx)):
             idx = None
 
         idx = group.get_next_idx(idx=idx, model_name=model)
@@ -700,7 +701,7 @@ class System:
     def precompile(self,
                    models: Union[OrderedDict, None] = None,
                    nomp: bool = False,
-                   ncpu: int = os.cpu_count()):
+                   ncpu: int = NCPUS_PHYSICAL):
         """
         Trigger precompilation for the given models.
 
@@ -1076,7 +1077,10 @@ class System:
 
         if self.config.ipadd:
             self.dae.gy.ipset(self.config.diag_eps, aidx, aidx)
+            self.dae.gy.ipset(0.0, aidx, vidx)
+
             self.dae.gy.ipset(self.config.diag_eps, vidx, vidx)
+            self.dae.gy.ipset(0.0, vidx, aidx)
         else:
             avals = [-self.dae.gy[int(idx), int(idx)] + self.config.diag_eps for idx in aidx]
             vvals = [-self.dae.gy[int(idx), int(idx)] + self.config.diag_eps for idx in vidx]
@@ -1804,6 +1808,9 @@ class System:
                 # link to the group
                 group_name = self.__dict__[model_name].group
                 self.__dict__[group_name].add_model(model_name, self.__dict__[model_name])
+        for key, val in andes.models.model_aliases.items():
+            self.model_aliases[key] = self.models[val]
+            self.__dict__[key] = self.models[val]
 
     def import_routines(self):
         """
