@@ -1,10 +1,10 @@
 """
 Utility functions for loading andes stock test cases
 """
-import os
-import tempfile
-import pathlib
 import logging
+import os
+import pathlib
+import tempfile
 
 logger = logging.getLogger(__name__)
 
@@ -79,10 +79,22 @@ class DisplayablePath:
         return ''.join(reversed(parts))
 
 
-def cases_root():
-    """Return the root path to the stock cases"""
+def andes_root():
+    """
+    Return the root path to the andes source code.
+    """
+
     dir_name = os.path.dirname(os.path.abspath(__file__))
-    return os.path.join(dir_name, '..', 'cases')
+    return os.path.normpath(os.path.join(dir_name, '..'))
+
+
+def cases_root():
+    """
+    Return the root path to the stock cases
+    """
+
+    dir_name = os.path.dirname(os.path.abspath(__file__))
+    return os.path.normpath(os.path.join(dir_name, '..', 'cases'))
 
 
 def tests_root():
